@@ -311,7 +311,7 @@ class CLI(object):
 				elif "//" in lexecutable: lexecutable = lexecutable.replace("//","/")
 				else: break
 			for i in sys.argv:
-				if i not in ["", lexecutable] and not os.path.exists(i) and (len(i) < 1 or (i[0] == "-")):
+				if i not in ["", lexecutable] and not Files.exists(i) and (len(i) < 1 or (i[0] == "-")):
 					if i not in exceptions and f" {i}: " not in self.modes_str and f" {i}: " not in self.options_str and f" {i} " not in self.modes_str and f" {i} " not in self.options_str:
 						error = f"Argument [{i}] is not a valid mode nor option."
 						if json:
@@ -534,7 +534,7 @@ class CLI(object):
 								include = False
 					if include: new += line+"\n"
 				if mode != None and (f" {mode}: " in new or f" {mode} " in new):
-					id = Formats.String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
+					id = String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
 					s = new.split(id)
 					before = s[0]+id
 					_new_, include, indent = "", False, None
@@ -551,7 +551,7 @@ class CLI(object):
 				else:
 					docs = before + new + after
 			if mode != None and (f" {mode}: " in new or f" {mode} " in new):
-				id = Formats.String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
+				id = String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
 				s = docs.split(id)
 				before = s[0]+id
 				_new_, include, indent = "", False, None
