@@ -3,7 +3,7 @@
 
 # imports.
 import os, sys, ast, json, glob, platform, subprocess, random
-from fil3s import Files, Formats
+from fil3s import *
 from r3sponse import r3sponse
 
 # functions.
@@ -15,9 +15,13 @@ def __get_operating_system__():
 
 # source.
 SOURCE_NAME = ALIAS = "cl1"
-SOURCE_PATH = Formats.FilePath(__file__).base(back=3)
+SOURCE_PATH = FilePath(__file__).base(back=3)
 OS = __get_operating_system__()
 
+# version.
+try: version = Files.load(f"{SOURCE_PATH}/.version")
+except: version = "unkown"
+
 # universal variables.
 OWNER = os.environ.get("USER")
 GROUP = "root"
